package com.ozs.system.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ozs.common.core.domain.entity.SysDictType;
import com.ozs.common.core.domain.vo.SysLoginInfoResq;
import com.ozs.common.core.domain.vo.SysLoginInfoVo;
import com.ozs.system.mapper.SysDictTypeMapper;
import icu.mhb.mybatisplus.plugln.base.service.impl.JoinServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ozs.system.domain.SysLoginInfo;
import com.ozs.system.mapper.SysLoginInfoMapper;
import com.ozs.system.service.ISysLoginInfoService;

/**
 * 系统访问日志情况信息 服务层处理
 *
 * @author hx
 */
@Service
public class SysLoginInfoServiceImpl extends JoinServiceImpl<SysLoginInfoMapper, SysLoginInfo> implements ISysLoginInfoService {

    @Autowired
    private SysLoginInfoMapper logininforMapper;

    /**
     * 新增系统登录日志
     *
     * @param logininfor 访问日志对象
     */
    @Override
    public void insertLogininfor(SysLoginInfo logininfor) {
        logininforMapper.insertLogininfor(logininfor);
    }

    public IPage listToPage(List list, int pageNum, int pageSize) {
        List pageList = new ArrayList<>();
        int curIdx = pageNum > 1 ? (pageNum - 1) * pageSize : 0;
        for (int i = 0; i < pageSize && curIdx + i < list.size(); i++) {
            pageList.add(list.get(curIdx + i));
        }
        IPage page = new Page<>(pageNum, pageSize);
        page.setRecords(pageList);
        page.setTotal(list.size());
        return page;
    }
    /**
     * 查询系统登录日志集合
     *
     * @param sysLoginInfoResq 访问日志对象
     * @return 登录记录集合
     */
    @Override
    public List<SysLoginInfo> selectLogininforList(SysLoginInfoResq sysLoginInfoResq) {
        return logininforMapper.selectLogininforList(sysLoginInfoResq);
    }

    /**
     * 批量删除系统登录日志
     *
     * @param infoIds 需要删除的登录日志ID
     * @return 结果
     */
    @Override
    public int deleteLogininforByIds(Long[] infoIds) {
        return logininforMapper.deleteLogininforByIds(infoIds);
    }

    /**
     * 清空系统登录日志
     */
    @Override
    public void cleanLogininfor() {
        logininforMapper.cleanLogininfor();
    }

    @Override
    public SysLoginInfo getLoginTime(String userName) {
        return logininforMapper.getLoginTime(userName);
    }

    /**
     * 查询登录日志详细
     *
     * @param infoId 日志ID
     * @return 登录日志对象
     */
    @Override
    public SysLoginInfo selectLoginLogById(Long infoId) {
        return logininforMapper.selectLoginLogById(infoId);
    }
}
